Response Processing
===================

.. py:module:: pyslet.qtiv2.processing


Generalized Response Processing
-------------------------------

..	autoclass:: ResponseProcessing
	:members:
	:show-inheritance:


..	autoclass:: ResponseRule
	:members:
	:show-inheritance:


..	autoclass:: ResponseCondition
	:members:
	:show-inheritance:


..	autoclass:: ResponseIf
	:members:
	:show-inheritance:


..	autoclass:: ResponseElseIf
	:members:
	:show-inheritance:


..	autoclass:: ResponseElse
	:members:
	:show-inheritance:


..	autoclass:: SetOutcomeValue
	:members:
	:show-inheritance:


..	autoclass:: StopProcessing
	:members:
	:show-inheritance:

..	autoclass:: ExitResponse
	:members:
	:show-inheritance:


Template Processing
===================

..	autoclass:: TemplateProcessing
	:members:
	:show-inheritance:


..	autoclass:: TemplateRule
	:members:
	:show-inheritance:


..	autoclass:: TemplateCondition
	:members:
	:show-inheritance:


..	autoclass:: TemplateIf
	:members:
	:show-inheritance:


..	autoclass:: TemplateElseIf
	:members:
	:show-inheritance:


..	autoclass:: TemplateElse
	:members:
	:show-inheritance:


..	autoclass:: SetTemplateValue
	:members:
	:show-inheritance:


..	autoclass:: SetCorrectResponse
	:members:
	:show-inheritance:


..	autoclass:: SetDefaultValue
	:members:
	:show-inheritance:


..	autoclass:: ExitTemplate
	:members:
	:show-inheritance:


Pre-conditions and Branching
============================


..	autoclass:: TestPartCondition
	:members:
	:show-inheritance:


..	autoclass:: PreCondition
	:members:
	:show-inheritance:


..	autoclass:: BranchRule
	:members:
	:show-inheritance:

..	autoclass:: TemplateDefault
	:members:
	:show-inheritance:
